@@ -2,7 +2,7 @@
 from typing import Optional, List
 from ..exceptions import WSTypeError, DelayedError, FeedError
 from ..rest import Authenticator
-from ..config import market_data_socket_urls, market_data_feedb_socket_urls, MAX_WS_RECONNECT_RETRIES, VALID_STREAM_TYPES, VALID_EXCHANGES, VALID_MARKET_DATA_TYPES, VALID_MARKET_DATA_SUBTYPES, REALTIME, B3, TRADES, INDICES, ALL, STOCKS, BOOKS
+from ..config import market_data_socket_urls, market_data_feedb_socket_urls, MAX_WS_RECONNECT_RETRIES, VALID_STREAM_TYPES, VALID_EXCHANGES, VALID_MARKET_DATA_TYPES, VALID_MARKET_DATA_SUBTYPES, REALTIME, B3, TRADES, INDICES, ALL, STOCKS, BOOKS, FEED_A, FEED_B
 from .websocket_default_functions import _on_open, _on_message, _on_error, _on_close
 import websocket
 import json
@@ -80,7 +80,7 @@ class MarketDataWebSocketClient:
         data_subtype: Optional[str] = None,
         instruments: Optional[List[str]] = [],
         ssl: Optional[bool] = True,
-        feed: Optional[str] = "A",
+        feed: Optional[str] = FEED_A,
         **kwargs,
     ):
         self.api_key = api_key
@@ -114,7 +114,7 @@ class MarketDataWebSocketClient:
             raise FeedError(
                 f"Must provide a valid 'data_subtype' parameter. Valid options are: {VALID_MARKET_DATA_SUBTYPES}")
 
-        if feed == "B":
+        if feed == FEED_B:
             url_feed_map = market_data_feedb_socket_urls
         else:
             url_feed_map = market_data_socket_urls
@@ -267,7 +267,7 @@ class MarketDataWebSocketClient:
         """
         self.ws.close()
 
-    def subscribe(self, list_instruments, n=None):
+    def subscribe(self, list_instruments, n=None, initial_snapshot: bool=False):
         """
         Subscribes a list of instruments.
 
@@ -278,12 +278,19 @@ class MarketDataWebSocketClient:
         n: int
             Field is not required.
             **For books data_type only.**
-            Maximum book level. It must be between 1 and 10.    
+            Maximum book level. It must be between 1 and 10. 
+        initial_snapshot: float
+            If True, client receives ticker last event (snapshot) of the provided ticker. 
+            Field is not required.
+            Default: False
         """
 
-        if self.data_type == BOOKS and n is not None:
-            self.__send({'action': 'subscribe', 'params': {"tickers": list_instruments, "n": n}})
-            self.__print(f'Socket subscribed the following instrument(s) with n = {n}: {list_instruments}')
+        if initial_snapshot or n is not None:
+            message = {'action': 'subscribe', 'params': {"tickers": list_instruments, "initial_snapshot": initial_snapshot}}
+            if n is not None:
+                message['params']['n'] = n
+            self.__send(message)
+            self.__print(f'Socket subscribed the following instrument(s) with n = {n}: {list_instruments} and initial_snapshot = {initial_snapshot}')
         else:
             self.__send({'action': 'subscribe', 'params': list_instruments})
             self.__print(f'Socket subscribed the following instrument(s): {list_instruments}')
